% RivLoadCalc 27-May-2019 

% Compute estimated loads at daily resolution for the 6 river sources:
%  Blackstone, Moshassuck, Pawtuxet, Taunton, TenMile, Woonasquatucket.
% Save each river's results in a mat file and plot, using a format uniform 
%      to all 18 sources in the overall analysis.
% Input data: files created by Inventory module.

% methods notes:

% Have TN from ~2012 onward. Have TDN from 2005 to 2012. Use TDN + constant
%   to estimate TN from 2005-2012, where constant is mean difference b/w
%   TN and TDN from 2012 onward. For pre-2005 use mean seasonal cycle 
%   (bimonthly) computed using 2005-2011. 
% Outliers removed but only for some rivers (Moshassuck, Woon).
% TenMile special case, missing Nov/Dec 2017, filled with mean seasonal 
%   cycle based on 2013-2016.

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

%% initial prep
ddn = datenum(2001,1,1):datenum(2017,12,31); % daily dn
% 1 MGD * mg/L = 8.338 lb/d = 3043 lb/y
newrdme = 'ddn = daily datenum; TNload [lb/y]; TNconc [mg/l]; Qflow [MGD]';

%% Blackstone
nam = 'Blackstone';
fprintf([nam '\n']);

load([indir nam]);
readme = newrdme;

% compute constant offset between TDN and TN
offset = max(nanmean(TN-TDN),0);
% where needed, fill TN by TDN+offset
TNc = TN;
TNc(isnan(TNc)) = TDN(isnan(TNc)) + offset;
% interp to daily 
TNconc = interp1(Cdn,TNc,ddn);
% fill out end of 2017
TNconc(isnan(TNconc) & ddn>datenum(2017,12,1)) = TNc(end);

%% compute mean seasonal TN cycle over years <= maxyr
maxyr = 2011;
bimnthlymn = [];
[~,mon,~] = datevec(Cdn);
mon = mon-1; % so that months 12-1, 2-3, 4-5 ... get averaged
mon(mon==0) = 12;
for i = 1:6
    whr = find((mon==2*(i-1)+1 | mon==2*(i-1)+2) & ...
                Cdn <= datenum(maxyr,12,31));
    bimnthlymn = [bimnthlymn nanmean(TNc(whr))];
    clear whr;
end
clear i mon maxyr;
meanseas = nan*ones(size(ddn));
for yr = 2001:2017
    for i = 1:6
        meanseas(find(ddn==datenum(yr,2*i,1))) = ...
            bimnthlymn(i);
    end
end
clear yr i;
meanseas(1)= mean([bimnthlymn(1) bimnthlymn(end)]);
meanseas(end)= mean([bimnthlymn(1) bimnthlymn(end)]);
clear bimnthlymn;
ind = ~isnan(meanseas);
meanseas = interp1(ddn(ind),meanseas(ind),ddn);
clear ind;
% put seasmean in to early years of TN.daily
whr = min(find(~isnan(TNconc)));
TNconc(1:whr) = meanseas(1:whr);
clear whr meanseas TNc Cdn TN TDN offset;

% flow
Qflow = Q';
clear Qdn Q;
% load
TNload = 3043*Qflow.*TNconc; % 1 MGD * mg/L = 8.338 lb/d = 3043 lb/y

eval(sprintf('save dat/%s readme TNload TNconc Qflow ddn;',nam));

makeplot(nam,ddn,TNload,TNconc,Qflow);

clear TNconc TNload Qflow;

%% Moshassuck
nam = 'Moshassuck';
fprintf([nam '\n']);

load([indir nam]);
readme = newrdme;

% compute constant offset between TDN and TN
offset = max(nanmean(TN-TDN),0);
% where needed, fill TN by TDN+offset
TNc = TN;
TNc(isnan(TNc)) = TDN(isnan(TNc)) + offset;
% remove a few outliers
TNc = myfo('TNc',TNc,'nearest','movmedian',20,4,0);
% interp to daily 
TNconc = interp1(Cdn,TNc,ddn);
% fill out end of 2017
TNconc(isnan(TNconc) & ddn>datenum(2017,12,1)) = TNc(end);

%% compute mean seasonal TN cycle over years <= maxyr
maxyr = 2011;
bimnthlymn = [];
[~,mon,~] = datevec(Cdn);
mon = mon-1; % so that months 12-1, 2-3, 4-5 ... get averaged
mon(mon==0) = 12;
for i = 1:6
    whr = find((mon==2*(i-1)+1 | mon==2*(i-1)+2) & ...
                Cdn <= datenum(maxyr,12,31));
    bimnthlymn = [bimnthlymn nanmean(TNc(whr))];
    clear whr;
end
clear i mon maxyr;
meanseas = nan*ones(size(ddn));
for yr = 2001:2017
    for i = 1:6
        meanseas(find(ddn==datenum(yr,2*i,1))) = ...
            bimnthlymn(i);
    end
end
clear yr i;
meanseas(1)= mean([bimnthlymn(1) bimnthlymn(end)]);
meanseas(end)= mean([bimnthlymn(1) bimnthlymn(end)]);
clear bimnthlymn;
ind = ~isnan(meanseas);
meanseas = interp1(ddn(ind),meanseas(ind),ddn);
clear ind;
% put seasmean in to early years of TN.daily
whr = min(find(~isnan(TNconc)));
TNconc(1:whr) = meanseas(1:whr);
clear whr meanseas TNc Cdn TN TDN offset;

% flow
Qflow = Q';
clear Qdn Q;
% load
TNload = 3043*Qflow.*TNconc; % 1 MGD * mg/L = 8.338 lb/d = 3043 lb/y

eval(sprintf('save dat/%s readme TNload TNconc Qflow ddn;',nam));

makeplot(nam,ddn,TNload,TNconc,Qflow);

clear TNconc TNload Qflow;


%% Pawtuxet
nam = 'Pawtuxet';
fprintf([nam '\n']);

load([indir nam]);
readme = newrdme;

% compute constant offset between TDN and TN
offset = max(nanmean(TN-TDN),0);
% where needed, fill TN by TDN+offset
TNc = TN;
TNc(isnan(TNc)) = TDN(isnan(TNc)) + offset;
% interp to daily 
TNconc = interp1(Cdn,TNc,ddn);
% fill out end of 2017
TNconc(isnan(TNconc) & ddn>datenum(2017,12,1)) = TNc(end);

%% compute mean seasonal TN cycle over years <= maxyr
maxyr = 2011;
bimnthlymn = [];
[~,mon,~] = datevec(Cdn);
mon = mon-1; % so that months 12-1, 2-3, 4-5 ... get averaged
mon(mon==0) = 12;
for i = 1:6
    whr = find((mon==2*(i-1)+1 | mon==2*(i-1)+2) & ...
                Cdn <= datenum(maxyr,12,31));
    bimnthlymn = [bimnthlymn nanmean(TNc(whr))];
    clear whr;
end
clear i mon maxyr;
meanseas = nan*ones(size(ddn));
for yr = 2001:2017
    for i = 1:6
        meanseas(find(ddn==datenum(yr,2*i,1))) = ...
            bimnthlymn(i);
    end
end
clear yr i;
meanseas(1)= mean([bimnthlymn(1) bimnthlymn(end)]);
meanseas(end)= mean([bimnthlymn(1) bimnthlymn(end)]);
clear bimnthlymn;
ind = ~isnan(meanseas);
meanseas = interp1(ddn(ind),meanseas(ind),ddn);
clear ind;
% put seasmean in to early years of TN.daily
whr = min(find(~isnan(TNconc)));
TNconc(1:whr) = meanseas(1:whr);
clear whr meanseas TNc Cdn TN TDN offset;

% flow
Qflow = Q';
clear Qdn Q;
% load
TNload = 3043*Qflow.*TNconc; % 1 MGD * mg/L = 8.338 lb/d = 3043 lb/y

eval(sprintf('save dat/%s readme TNload TNconc Qflow ddn;',nam));

makeplot(nam,ddn,TNload,TNconc,Qflow);

clear TNconc TNload Qflow;

%% Taunton
nam = 'Taunton';
fprintf([nam '\n']);

load([indir nam]);
readme = newrdme;

% compute constant offset between TDN and TN
offset = max(nanmean(TN-TDN),0);
% where needed, fill TN by TDN+offset
TNc = TN;
TNc(isnan(TNc)) = TDN(isnan(TNc)) + offset;
% interp to daily 
TNconc = interp1(Cdn,TNc,ddn);
% fill out end of 2017
TNconc(isnan(TNconc) & ddn>datenum(2017,12,1)) = TNc(end);

%% compute mean seasonal TN cycle over years <= maxyr
maxyr = 2011;
bimnthlymn = [];
[~,mon,~] = datevec(Cdn);
mon = mon-1; % so that months 12-1, 2-3, 4-5 ... get averaged
mon(mon==0) = 12;
for i = 1:6
    whr = find((mon==2*(i-1)+1 | mon==2*(i-1)+2) & ...
                Cdn <= datenum(maxyr,12,31));
    bimnthlymn = [bimnthlymn nanmean(TNc(whr))];
    clear whr;
end
clear i mon maxyr;
meanseas = nan*ones(size(ddn));
for yr = 2001:2017
    for i = 1:6
        meanseas(find(ddn==datenum(yr,2*i,1))) = ...
            bimnthlymn(i);
    end
end
clear yr i;
meanseas(1)= mean([bimnthlymn(1) bimnthlymn(end)]);
meanseas(end)= mean([bimnthlymn(1) bimnthlymn(end)]);
clear bimnthlymn;
ind = ~isnan(meanseas);
meanseas = interp1(ddn(ind),meanseas(ind),ddn);
clear ind;
% put seasmean in to early years of TN.daily
whr = min(find(~isnan(TNconc)));
TNconc(1:whr) = meanseas(1:whr);
clear whr meanseas TNc Cdn TN TDN offset;

% flow
Qflow = Q';
clear Qdn Q;
% load
TNload = 3043*Qflow.*TNconc; % 1 MGD * mg/L = 8.338 lb/d = 3043 lb/y

eval(sprintf('save dat/%s readme TNload TNconc Qflow ddn;',nam));

makeplot(nam,ddn,TNload,TNconc,Qflow);

clear TNconc TNload Qflow;

%% TenMile
nam = 'TenMile';
fprintf([nam '\n']);

load([indir nam]);
readme = newrdme;

% compute constant offset between TDN and TN
offset = max(nanmean(TN-TDN),0);
% where needed, fill TN by TDN+offset
TNc = TN;
TNc(isnan(TNc)) = TDN(isnan(TNc)) + offset;
clear offset TDN;
% interp to daily 
TNconc = interp1(Cdn,TNc,ddn);

% don't use fillmissing on end of 2017 (special case: missing nov & dec)
% instead fill it w/ mean seas cycle of 2013-2016
bimnthlymn = [];
[~,mon,~] = datevec(Cdn);
mon = mon-1; % so that months 12-1, 2-3, 4-5 ... get averaged
mon(mon==0) = 12;
for i = 1:6
    whr = find((mon==2*(i-1)+1 | mon==2*(i-1)+2) & ...
                Cdn >= datenum(2013,1,1) & Cdn <=datenum(2016,12,31));
    bimnthlymn = [bimnthlymn nanmean(TNc(whr))];
    clear whr;
end
clear i mon maxyr;
meanseas = nan*ones(size(ddn));
for yr = 2001:2017
    for i = 1:6
        meanseas(find(ddn==datenum(yr,2*i,1))) = ...
            bimnthlymn(i);
    end
end
clear yr i;
meanseas(1)= mean([bimnthlymn(1) bimnthlymn(end)]);
meanseas(end)= mean([bimnthlymn(1) bimnthlymn(end)]);
clear bimnthlymn;
strt = max(find(~isnan(TNconc)));
whr = find(ddn>ddn(strt));
TNconc(whr) = meanseas(whr);
TNconc([min(whr)-1 whr]) = interp1(ddn(~isnan(TNconc)),...
    TNconc(~isnan(TNconc)),ddn([min(whr)-1 whr]));

clear whr meanseas TN TDN;

%% For early years: compute mean seasonal TN cycle over years <= maxyr
maxyr = 2011;
bimnthlymn = [];
[~,mon,~] = datevec(Cdn);
mon = mon-1; % so that months 12-1, 2-3, 4-5 ... get averaged
mon(mon==0) = 12;
for i = 1:6
    whr = find((mon==2*(i-1)+1 | mon==2*(i-1)+2) & ...
                Cdn <= datenum(maxyr,12,31));
    bimnthlymn = [bimnthlymn nanmean(TNc(whr))];
    clear whr;
end
clear i mon maxyr;
meanseas = nan*ones(size(ddn));
for yr = 2001:2017
    for i = 1:6
        meanseas(find(ddn==datenum(yr,2*i,1))) = ...
            bimnthlymn(i);
    end
end
clear yr i;
meanseas(1)= mean([bimnthlymn(1) bimnthlymn(end)]);
meanseas(end)= mean([bimnthlymn(1) bimnthlymn(end)]);
clear bimnthlymn;
ind = ~isnan(meanseas);
meanseas = interp1(ddn(ind),meanseas(ind),ddn);
clear ind;
% put seasmean in to early years of TN.daily
whr = min(find(~isnan(TNconc)));
TNconc(isnan(TNconc)) = meanseas(isnan(TNconc));
clear whr meanseas TNc Cdn TN TDN offset;

% flow
Qflow = Q';
clear Qdn Q;
% load
TNload = 3043*Qflow.*TNconc; % 1 MGD * mg/L = 8.338 lb/d = 3043 lb/y

eval(sprintf('save dat/%s readme TNload TNconc Qflow ddn;',nam));

makeplot(nam,ddn,TNload,TNconc,Qflow);

clear TNconc TNload Qflow;

%% Woonasquatucket
nam = 'Woonasquatucket';
fprintf([nam '\n']);

load([indir nam]);
readme = newrdme;

% fill a few outliers in TDN
TDN = myfo('TDN',TDN,'nearest','movmedian',20,7,0);
% compute constant offset between TDN and TN
offset = max(nanmean(TN-TDN),0);
% where needed, fill TN by TDN+offset
TNc = TN;
TNc(isnan(TNc)) = TDN(isnan(TNc)) + offset;
% interp to daily 
TNconc = interp1(Cdn,TNc,ddn);
% fill out end of 2017
TNconc(isnan(TNconc) & ddn>datenum(2017,12,1)) = TNc(end);

%% compute mean seasonal TN cycle over years <= maxyr
maxyr = 2011;
bimnthlymn = [];
[~,mon,~] = datevec(Cdn);
mon = mon-1; % so that months 12-1, 2-3, 4-5 ... get averaged
mon(mon==0) = 12;
for i = 1:6
    whr = find((mon==2*(i-1)+1 | mon==2*(i-1)+2) & ...
                Cdn <= datenum(maxyr,12,31));
    bimnthlymn = [bimnthlymn nanmean(TNc(whr))];
    clear whr;
end
clear i mon maxyr;
meanseas = nan*ones(size(ddn));
for yr = 2001:2017
    for i = 1:6
        meanseas(find(ddn==datenum(yr,2*i,1))) = ...
            bimnthlymn(i);
    end
end
clear yr i;
meanseas(1)= mean([bimnthlymn(1) bimnthlymn(end)]);
meanseas(end)= mean([bimnthlymn(1) bimnthlymn(end)]);
clear bimnthlymn;
ind = ~isnan(meanseas);
meanseas = interp1(ddn(ind),meanseas(ind),ddn);
clear ind;
% put seasmean in to early years of TN.daily
whr = min(find(~isnan(TNconc)));
TNconc(1:whr) = meanseas(1:whr);
clear whr meanseas TNc Cdn TN TDN offset;

% flow
Qflow = Q';
clear Qdn Q;
% load
TNload = 3043*Qflow.*TNconc; % 1 MGD * mg/L = 8.338 lb/d = 3043 lb/y

eval(sprintf('save dat/%s readme TNload TNconc Qflow ddn;',nam));

makeplot(nam,ddn,TNload,TNconc,Qflow);

clear TNconc TNload Qflow;




% end of module
diary off;