% RI7LoadCalc 07-Apr-2019 

% Compute estimated loads at daily resolution for the 7 RI WWTFs other than
% FP and BP: 
%   EGwch, EProv, Quon, Brist, Warr, Jmstwn, Newp.
% Save each WWTF's results in a mat file and a plot, using a format uniform 
%      to all 18 sources in the overall analysis.
% Input data: files created from RIDEM spreadsheet by Inventory module.

% About Fields and Bucklin in this file: They are treated, similarly to
%   the others. However the results are only used for pre-2004. See FPBP
%   modules, in which post-2004 loads are computed using data obtained 
%   from NBC directly, which have higher frequency than the data treated
%   here (obtained from RIDEM) during those years. The data here are used,
%   but only a patch by the FPBP moduled to fill in the early years.

% notes on methods:

%% Fields Point
% Used TN-Avg, replaced by TN-Max when not available, for ~2002 onward. 
%   Pre-2002, used regression b/w TN-Avg and Sum(NO2,NO3,NH4). 

%% Bucklin Point
% Used TN-Avg, replaced by TN-Max when not available, for ~2002 onward. 
%   Pre-2002, used regression b/w TN-Avg and Sum(NO2,NO3,NH4). 

%% East Greenwich
% Used TN-Avg (available all years).

%% EastProvidence
% Used TN-Avg since Aug 2005, not available earlier. Used TN-Max from Feb 
%   2002-Aug 2005. (When TN-Max is available but not TN-Avg, TN-Max 
%   is representative of the average.) For before Feb 2002, used regression 
%   b/w TN-Avg and Sum(NO2,NO3,NH4) during available pre-2008 years.

%% Quonset
% No TN-Avg available. Used TN-Max (available all years). (When TN-Max is 
%   available but not TN-Avg, TN-Max is representative of the average.)

%% Bristol
% Used TN-Avg, replaced by TN-Max when not available, for ~2005 onward. 
%   Pre-2005, used regression b/w TN-Avg and Sum(NO3-Avg,TKN-Avg), where 
%   missing NO3-Avg were filled by replacement with NO3-Mx and missing 
%   TKN-Avg were filled by replacement with TKN-Mx.

%% Warren
% Used TN-Avg, replaced by TN-Max when not available, for ~2002 onward. 
%   Pre-2002, used regression b/w TN-Avg and TKN-Avg, where 
%   missing TKN-Avg were filled by replacement with TKN-Mx.

%% Jamestown
% For May to Oct:
%   Since 2005, used TN-Avg (very recent years) or TN-Max when TN-Avg 
%      not available. (When TN-Max is available but not TN-Avg, TN-Max 
%      is representative of the average.)
%   Prior to 2005, used sum of NO2, NO3, and TKN.
% For Nov to Apr (no observations available):
%   Used mean value of all years May-Oct, as somewhat justified based on 
%     examination of nearby plants with year-round data (Quonset, Bristol) 
%     for which the difference between longterm mean Nov-Apr and May-Oct 
%     values was smaller than the typical variability during each year.

%% Newport
% For May to Oct:
%   Since 2008, used TN-Avg (very recent years) or TN-Max when TN-Avg 
%      not available. (When TN-Max is available but not TN-Avg, TN-Max 
%      is representative of the average.)
%   Before 2008, no data available. Use monthly means of post-2008 years.
% For Nov to Apr (no observations available):
%   Used mean value of all years May-Oct, as somewhat justified based on 
%     examination of nearby plants with year-round data (Quonset, Bristol) 
%     for which the difference between longterm mean Nov-Apr and May-Oct 
%     values was smaller than the typical variability during each year.

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

%% initial prep
ddn = datenum(2001,1,1):datenum(2017,12,31); % daily dn
% 1 MGD * mg/L = 8.338 lb/d = 3043 lb/y
newrdme = 'ddn = daily datenum; TNload [lb/y]; TNconc [mg/l]; Qflow [MGD]';
pltdir = ['C:\dc\consult\2018nbep\analysis\NutrientLoads\WWTFs\'...
    'RI7\RI7LoadCalc\plt'];
% 1 to force preview of all filloutliers calls; 0 to skip them
pse = 0;

%% FieldsPoint
nam = 'FieldsPoint';
fprintf([nam '\n']);

load([indir nam]);
readme = newrdme;
%   NO3: fill outliers
% NO3.Mx = myfo('NO3.Mx',NO3.Mx,'nearest','movmedian',12,6,pse);
%   NO2: fill outliers
NO2.Mx = myfo('NO2.Mx',NO2.Mx,'nearest','movmedian',12,6,pse);
%   NH4: fill outliers
% NH4.Mx = myfo('NH4.Mx',NH4.Mx,'nearest','movmedian',12,6,pse);

%   TN: fill outliers
% TN.Mx = myfo('TN.Mx',TN.Mx,'nearest','movmedian',12,6,pse);
% TN.Av = myfo('TN.Av',TN.Av,'nearest','movmedian',12,6,pse);

%   TN: use Av where available, otherwise use Mx 
whr = isnan(TN.Av) & ~isnan(TN.Mx);
TN.Av(whr) = TN.Mx(whr);
clear whr;
%   TN: fill missing using regression against NO3+NO2+NH4
mdli = NO3.Mx+NO2.Mx+NH4.Mx;
mdlo = TN.Av;
mdlo(isnan(mdlo)) = estbyregr(mdli,mdlo,'linear',mdli(isnan(mdlo)),...
    pltdir,[nam '-TNAvfromSumNO2NO3NH4']);
TN.Av = mdlo;
clear mdli mdlo;
% Concentration [mg/l]
%   interp from monthly values to daily
TNconc = interp1(dn,TN.Av,ddn);
%   fill NaNs in first and last half-month using nearest value
TNconc = fillmissing(TNconc,'nearest');
% Flow [MGD]
%   fill outliers
% Q.Av = myfo('Q.Av',Q.Av,'nearest','movmedian',12,6,pse);

%   interp from monthly values to daily
Qflow = interp1(dn,Q.Av,ddn);
%   fill NaNs in first and last half-month using nearest value
Qflow = fillmissing(Qflow,'nearest');
% Load [lb/y]
TNload = 3043* TNconc.*Qflow;
eval(sprintf('save dat/%s readme TNload TNconc Qflow ddn;',nam));

makeplot(nam,ddn,TNload,TNconc,Qflow);

clear dn NH4 NO2 NO3 NO32 Q TKN TN TNLd TNconc TNload Qflow nam readme;

%% BucklinPoint
nam = 'BucklinPoint';
fprintf([nam '\n']);

load([indir nam]);
readme = newrdme;
%   NO3: fill outliers
% NO3.Mx = myfo('NO3.Mx',NO3.Mx,'nearest','movmedian',12,6,pse);
%   NO2: fill outliers
NO2.Mx = myfo('NO2.Mx',NO2.Mx,'nearest','movmedian',20,6,pse);
%   NH4: fill outliers
% NH4.Mx = myfo('NH4.Mx',NH4.Mx,'nearest','movmedian',12,6,pse);
%   TN: fill outliers
% TN.Mx = myfo('TN.Mx',TN.Mx,'nearest','movmedian',12,6,pse);
% TN.Av = myfo('TN.Av',TN.Av,'nearest','movmedian',12,6,pse);
%   TN: use Av where available, otherwise use Mx 
whr = isnan(TN.Av) & ~isnan(TN.Mx);
TN.Av(whr) = TN.Mx(whr);
clear whr;
%   TN: fill missing using regression against NO2+NO3+NH4
mdli = NO3.Mx+NO2.Mx+NH4.Mx;
mdlo = TN.Av;
mdlo(isnan(mdlo)) = estbyregr(mdli,mdlo,'linear',mdli(isnan(mdlo)),...
    pltdir,[nam '-TNAvfromSumNO2NO3NH4']);
TN.Av = mdlo;
clear mdli mdlo;
% Concentration [mg/l]
%   interp from monthly values to daily
TNconc = interp1(dn,TN.Av,ddn);
%   fill NaNs in first and last half-month using nearest value
TNconc = fillmissing(TNconc,'nearest');
% Flow [MGD]
%   fill outliers
% Q.Av = myfo('Q.Av',Q.Av,'nearest','movmedian',12,6,pse);

%   interp from monthly values to daily
Qflow = interp1(dn,Q.Av,ddn);
%   fill NaNs in first and last half-month using nearest value
Qflow = fillmissing(Qflow,'nearest');
% Load [lb/y]
TNload = 3043* TNconc.*Qflow;
eval(sprintf('save dat/%s readme TNload TNconc Qflow ddn;',nam));

makeplot(nam,ddn,TNload,TNconc,Qflow);

clear dn NH4 NO2 NO3 NO32 Q TKN TN TNLd TNconc TNload Qflow nam readme;

%% East Greenwich
nam = 'EastGreenwich';
fprintf([nam '\n']);

load([indir nam]);
readme = newrdme;
% Concentration [mg/l]
%   fill outliers
% TN.Av = myfo('TN.Av',TN.Av,'nearest','movmedian',12,6,pse);
%   interp from monthly values to daily
TNconc = interp1(dn,TN.Av,ddn);
%   fill NaNs in first and last half-month using nearest value
TNconc = fillmissing(TNconc,'nearest');
% Flow [MGD]
%   fill outliers
% Q.Av = myfo('Q.Av',Q.Av,'nearest','movmedian',12,6,pse);
%   interp from monthly values to daily
Qflow = interp1(dn,Q.Av,ddn);
%   fill NaNs in first and last half-month using nearest value
Qflow = fillmissing(Qflow,'nearest');
% Load [lb/y]
TNload = 3043* TNconc.*Qflow;
eval(sprintf('save dat/%s readme TNload TNconc Qflow ddn;',nam));

makeplot(nam,ddn,TNload,TNconc,Qflow);

clear dn NH4 NO2 NO3 NO32 Q TKN TN TNLd TNconc TNload Qflow nam readme;

%% EastProvidence
nam = 'EastProvidence';
fprintf([nam '\n']);

load([indir nam]);
readme = newrdme;
% Concentration [mg/l]
%   fill outliers
% TN.Av = myfo('TN.Av',TN.Av,'nearest','movmedian',12,6,pse);

%   for Feb 2002 to Aug 2005 (TN.Av not avail):
%     use TN.Mx values to replace TN.Av values
TNc = TN.Av;
% TN.Mx = myfo('TN.Mx',TN.Mx,'nearest','movmedian',12,6,pse);

whr = find(isnan(TNc) & ~isnan(TN.Mx));
TNc(whr) = TN.Mx(whr);
clear whr;
%   for Jan 2001 to Feb 2002 (neither TN.Av nor TN.Mx avail):
%     use regression of TN.Av vs sum(NO2,NO3,NH4) during 2002-2007
whr = find(dn<datenum(2008,1,1));
mdli = NO2.Mx(whr) + NO3.Mx(whr) + NH4.Mx(whr);
mdlo = TNc(whr);
clear whr;
TNc(isnan(TNc)) = estbyregr(mdli,mdlo,'linear',mdli(isnan(mdlo)),...
    pltdir,[nam '-TNfromPre2008SumNO2NO3NH4']);
clear mdli mdlo;
%   interp from monthly values to daily
TNconc = interp1(dn,TNc,ddn);
clear TNc;
%   fill NaNs in first and last half-month using nearest value
TNconc = fillmissing(TNconc,'nearest');
% Flow [MGD]
%   fill outliers
% Q.Av = myfo('Q.Av',Q.Av,'nearest','movmedian',12,6,pse);

%   interp from monthly values to daily
Qflow = interp1(dn,Q.Av,ddn);
%   fill NaNs in first and last half-month using nearest value
Qflow = fillmissing(Qflow,'nearest');
% Load [lb/y]
TNload = 3043* TNconc.*Qflow;
eval(sprintf('save dat/%s readme TNload TNconc Qflow ddn;',nam));

makeplot(nam,ddn,TNload,TNconc,Qflow);

clear dn NH4 NO2 NO3 NO32 Q TKN TN TNLd TNconc TNload Qflow nam readme;

%% Quonset
nam = 'Quonset';
fprintf([nam '\n']);

load([indir nam]);
readme = newrdme;
% Concentration [mg/l] -- no Av available, have only Mx
%   fill outliers and interp from monthly values to daily
% TN.Mx = myfo('TN.Mx',TN.Mx,'nearest','movmedian',12,6,pse);
TNconc = interp1(dn,TN.Mx,ddn);
%   fill NaNs in first and last half-month using nearest value
TNconc = fillmissing(TNconc,'nearest');
% Flow [MGD]
%   fill outliers
% Q.Av = myfo('Q.Av',Q.Av,'nearest','movmedian',12,6,pse);

%   interp from monthly values to daily
Qflow = interp1(dn,Q.Av,ddn);
%   fill NaNs in first and last half-month using nearest value
Qflow = fillmissing(Qflow,'nearest');
% Load [lb/y]
TNload = 3043* TNconc.*Qflow;
eval(sprintf('save dat/%s readme TNload TNconc Qflow ddn;',nam));

makeplot(nam,ddn,TNload,TNconc,Qflow);

clear dn NH4 NO2 NO3 NO32 Q TKN TN TNLd TNconc TNload Qflow nam readme;

%% Bristol
nam = 'Bristol';
fprintf([nam '\n']);

load([indir nam]);
readme = newrdme;
%   NO3: fill outliers
% NO3.Mx = myfo('NO3.Mx',NO3.Mx,'nearest','movmedian',12,6,pse);
% NO3.Av = myfo('NO3.Av',NO3.Av,'nearest','movmedian',12,6,pse);

%   NO3: use Av where available and otherwise Mx
whr = isnan(NO3.Av) & ~isnan(NO3.Mx);
NO3.Av(whr) = NO3.Mx(whr);
clear whr;
%   NO3: linear interp to fill remaining one missing NO3.Av 
NO3.Av = fillmissing(NO3.Av,'linear');
%   TKN: fill outliers
TKN.Mx = myfo('TKN.Mx',TKN.Mx,'nearest','movmedian',12,6,pse);
TKN.Av = myfo('TKN.Av',TKN.Av,'nearest','movmedian',12,6,pse);

%   TKN: use Av where available and otherwise Mx
whr = isnan(TKN.Av) & ~isnan(TKN.Mx);
TKN.Av(whr) = TKN.Mx(whr);
clear whr;
%   TN: fill outliers
% TN.Mx = myfo('TN.Mx',TN.Mx,'nearest','movmedian',12,6,pse);
TN.Av = myfo('TN.Av',TN.Av,'nearest','movmedian',12,6,pse);

%   TN: use Av where available, otherwise use Mx 
whr = isnan(TN.Av) & ~isnan(TN.Mx);
TN.Av(whr) = TN.Mx(whr);
clear whr;
%   TN: fill missing using regression against NO3.Av+TKN.Av
mdli = NO3.Av+TKN.Av;
mdli = myfo('NO3.Av+TKN.Av',mdli,'nearest','movmedian',12,4,pse);
mdlo = TN.Av;
mdlo(isnan(mdlo)) = estbyregr(mdli,mdlo,'linear',mdli(isnan(mdlo)),...
    pltdir,[nam '-TNAvfromSumNO3TKN']);
TN.Av = mdlo;
clear mdli mdlo;
% Concentration [mg/l]
%   interp from monthly values to daily
TNconc = interp1(dn,TN.Av,ddn);
%   fill NaNs in first and last half-month using nearest value
TNconc = fillmissing(TNconc,'nearest');
% Flow [MGD]
%   fill outliers
% Q.Av = myfo('Q.Av',Q.Av,'nearest','movmedian',12,6,pse);
%   interp from monthly values to daily
Qflow = interp1(dn,Q.Av,ddn);
%   fill NaNs in first and last half-month using nearest value
Qflow = fillmissing(Qflow,'nearest');
% Load [lb/y]
TNload = 3043* TNconc.*Qflow;
eval(sprintf('save dat/%s readme TNload TNconc Qflow ddn;',nam));

makeplot(nam,ddn,TNload,TNconc,Qflow);

clear dn NH4 NO2 NO3 NO32 Q TKN TN TNLd TNconc TNload Qflow nam readme;

%% Warren
nam = 'Warren';
fprintf([nam '\n']);

load([indir nam]);
readme = newrdme;
%   TKN: fill outliers
% TKN.Mx = myfo('TKN.Mx',TKN.Mx,'nearest','movmedian',12,6,pse);
% TKN.Av = myfo('TKN.Av',TKN.Av,'nearest','movmedian',12,6,pse);

%   TKN: use Av where available and otherwise Mx
whr = isnan(TKN.Av) & ~isnan(TKN.Mx);
TKN.Av(whr) = TKN.Mx(whr);
clear whr;
%   TKN: linear interp to fill remaining few missing TKN.Av 
TKN.Av = fillmissing(TKN.Av,'linear');
%   TN: fill outliers
% TN.Mx = myfo('TN.Mx',TN.Mx,'nearest','movmedian',12,6,pse);
% TN.Av = myfo('TN.Av',TN.Av,'nearest','movmedian',12,6,pse);

%   TN: use Av where available, otherwise use Mx 
whr = isnan(TN.Av) & ~isnan(TN.Mx);
TN.Av(whr) = TN.Mx(whr);
clear whr;
%   TN: fill missing using regression against TKN.Av
mdli = TKN.Av;
mdlo = TN.Av;
mdlo(isnan(mdlo)) = estbyregr(mdli,mdlo,'linear',mdli(isnan(mdlo)),...
    pltdir,[nam '-TNAvfromTKN']);
TN.Av = mdlo;
clear mdli mdlo;
% Concentration [mg/l]
%   interp from monthly values to daily
TNconc = interp1(dn,TN.Av,ddn);
%   fill NaNs in first and last half-month using nearest value
TNconc = fillmissing(TNconc,'nearest');
% Flow [MGD]
%   fill outliers
% Q.Av = myfo('Q.Av',Q.Av,'nearest','movmedian',12,6,pse);

%   interp from monthly values to daily
Qflow = interp1(dn,Q.Av,ddn);
%   fill NaNs in first and last half-month using nearest value
Qflow = fillmissing(Qflow,'nearest');
% Load [lb/y]
TNload = 3043* TNconc.*Qflow;
eval(sprintf('save dat/%s readme TNload TNconc Qflow ddn;',nam));

makeplot(nam,ddn,TNload,TNconc,Qflow);

clear dn NH4 NO2 NO3 NO32 Q TKN TN TNLd TNconc TNload Qflow nam readme;

%% Jamestown
nam = 'Jamestown';
fprintf([nam '\n']);

load([indir nam]);
readme = newrdme;
% Concentration [mg/l]
%   First, NO2, NO3, and TKN (to be used for pre ~2005)
%     fill outliers
% NO2.Mx = myfo('NO2.Mx',NO2.Mx,'nearest','movmedian',12,6,pse);
% NO2.Av = myfo('NO2.Av',NO2.Av,'nearest','movmedian',12,6,pse);
% NO3.Mx = myfo('NO3.Mx',NO3.Mx,'nearest','movmedian',12,6,pse);
% NO3.Av = myfo('NO3.Av',NO3.Av,'nearest','movmedian',12,6,pse);
% TKN.Mx = myfo('TKN.Mx',TKN.Mx,'nearest','movmedian',12,6,pse);
% TKN.Av = myfo('TKN.Av',TKN.Av,'nearest','movmedian',12,6,pse);
%     merge Mx to Av, where don't have Av
NO2c = NO2.Av;
whr = find(isnan(NO2.Av) & ~isnan(NO2.Mx));
NO2c(whr) = NO2.Mx(whr);
NO3c = NO3.Av;
whr = find(isnan(NO3.Av) & ~isnan(NO3.Mx));
NO3c(whr) = NO3.Mx(whr);
TKNc = TKN.Av;
whr = find(isnan(TKN.Av) & ~isnan(TKN.Mx));
TKNc(whr) = TKN.Mx(whr);
clear whr;
%     linearly interp fill if b/w may & oct
for iy = 1:(length(dn)/12)
    NO2c((iy-1)*12+(5:10)) = fillmissing(NO2c((iy-1)*12+(5:10)),...
        'linear','EndValues','none');
    NO3c((iy-1)*12+(5:10)) = fillmissing(NO3c((iy-1)*12+(5:10)),...
        'linear','EndValues','none');
    TKNc((iy-1)*12+(5:10)) = fillmissing(TKNc((iy-1)*12+(5:10)),...
        'linear','EndValues','none');
end
clear iy;
%     endvalues -- substitue longterm mean annual cycle if b/w may & oct
annmn = nanmean(reshape(NO2c,12,17)');
annmn = repmat(annmn,1,length(NO2c)/12);
whr = find(isnan(NO2c));
NO2c(whr) = annmn(whr);
annmn = nanmean(reshape(NO3c,12,17)');
annmn = repmat(annmn,1,length(NO3c)/12);
whr = find(isnan(NO3c));
NO3c(whr) = annmn(whr);
annmn = nanmean(reshape(TKNc,12,17)');
annmn = repmat(annmn,1,length(TKNc)/12);
whr = find(isnan(TKNc));
TKNc(whr) = annmn(whr);
clear whr annmn;
%     sum NO2, NO3, and TKN (using nanmean; NO3 & TKN never both missing) 
TNc = sum([NO2c;NO3c;TKNc]);
clear NO2 NO2c NO3 NO3c TKN TKNc;
%  TN
%    use Mx where Av not available
TNconc = TN.Av;
whr = find(isnan(TNconc) & ~isnan(TN.Mx));
TNconc(whr) = TN.Mx(whr);
%    fill outliers
% TNconc = myfo('TNconc',TNconc,'nearest','movmedian',12,6,pse);

%    use NO2+NO3+TKN where Av and Mx not available
whr = find(isnan(TNconc) & ~isnan(TNc));
TNconc(whr) = TNc(whr);
clear whr TNc;
%    fill Nov-Apr with longterm mean
TNconc(isnan(TNconc)) = nanmean(TNconc);
%    interp from monthly values to daily
TNconc = interp1(dn,TNconc,ddn);
%    fill NaNs in first and last half-month using nearest value
TNconc = fillmissing(TNconc,'nearest');
% Flow [MGD]
%   fill outliers
Q.Av = myfo('Q.Av',Q.Av,'nearest','movmedian',12,6,pse);

%   interp from monthly values to daily
Qflow = interp1(dn,Q.Av,ddn);
%   fill NaNs in first and last half-month using nearest value
Qflow = fillmissing(Qflow,'nearest');
% Load [lb/y]
TNload = 3043* TNconc.*Qflow;
eval(sprintf('save dat/%s readme TNload TNconc Qflow ddn;',nam));

makeplot(nam,ddn,TNload,TNconc,Qflow);

clear dn NH4 NO2 NO3 NO32 Q TKN TN TNLd TNconc TNload Qflow nam readme;

%% Newport
nam = 'Newport';
fprintf([nam '\n']);

load([indir nam]);
readme = newrdme;
% Concentration [mg/l]
%  TN
%    use Mx where Av not available
TNconc = TN.Av;
whr = find(isnan(TNconc) & ~isnan(TN.Mx));
TNconc(whr) = TN.Mx(whr);
%    fill outliers
% TNconc = myfo('TNconc',TNconc,'nearest','movmedian',12,6,pse);

%    compute monthly means & substitute in early years
tmp = repmat(nanmean(reshape(TNconc,12,17)'),1,length(dn)/12);
whr = find(isnan(TNconc) & ~isnan(tmp));
TNconc(whr) = tmp(whr);
clear tmp whr;
%    fill Nov-Apr with longterm mean
TNconc(isnan(TNconc)) = nanmean(TNconc);
%    interp from monthly values to daily
TNconc = interp1(dn,TNconc,ddn);
%    fill NaNs in first and last half-month using nearest value
TNconc = fillmissing(TNconc,'nearest');
% Flow [MGD]
%   fill outliers
% Q.Av = myfo('Q.Av',Q.Av,'nearest','movmedian',12,6,pse);

%   interp from monthly values to daily
Qflow = interp1(dn,Q.Av,ddn);
%   fill NaNs in first and last half-month using nearest value
Qflow = fillmissing(Qflow,'nearest');
% Load [lb/y]
TNload = 3043* TNconc.*Qflow;
eval(sprintf('save dat/%s readme TNload TNconc Qflow ddn;',nam));

makeplot(nam,ddn,TNload,TNconc,Qflow);

clear dn NH4 NO2 NO3 NO32 Q TKN TN TNLd TNconc TNload Qflow nam readme;


% end of module
diary off;